**********************************************************************
* Duncan Amplfication Generic Triode Model (PSpice Implementation)
* Copyright (C)1997-2004 Duncan Amplfication
* Unauthorised Commercial use prohibited
* Please refer to documentation at http://www.duncanamps.com
*
* $MODEL_VERSION$ 4.1
* $AUTOGENERATED$ 23/01/2004 20:24:26 
**********************************************************************
.PARAM EMISSIONRANGE = 1
* CURRENT MODEL SET AND VERSIONS:
*
*       2A3                 [3.2, 09/08/2003 ]
*       3CX300              [3.1, 05/01/1998 ]
*       SV6AS7              [3.0, 30/12/1997 ]
*       6BM8 / ECL82        [3.0, 31/12/1997 ]
*       6DJ8 / ECC88        [3.0, 15/08/1998 ]
*       6N1P                [3.0, 25/01/1998 ]
*       6SN7GTB             [3.1, 05/01/1998 ]
*       12AT7 / ECC81       [3.1, 05/01/1998 ]
*       12AU7 / ECC82       [3.2, 01/05/2002 ]
*       12AX7 / ECC83       [3.0, 30/12/1997 ]
*       76                  [3.0, 12/02/1998 ]
*       300B                [3.1, 06/01/1998 ]
*       SV572-3             [3.0, 31/12/1997 ]
*       SV572-10            [3.0, 20/06/1998 ]
*       5751                [3.0, 15/02/1998 ]
*       D3A/7721 triode     Steve Bench
*       6C45-PE             Dave Slagle
*	VT-4C               Dave Slagle
*       Ba (PTT 2)          Aernoud Dekker
*	k2a3_sofia          Federico Scarpa
*	k300bb_sofia  	    Federico Scarpa
*	k5687wa       	    Federico Scarpa
*	k6c33c_sofia 	    Federico Scarpa
*	k6c4c		    Federico Scarpa
*	k6sn7_sofia	    Federico Scarpa
*	kel34_sofia	    Federico Scarpa
*	kecc99		    Federico Scarpa
*       kGM70		    Federico Scarpa
*	kvv30b_sofia	    Federico Scarpa
*
*  Added param EMISSIONRANGE to allow for device variation
**********************************************************************
* CORE MODEL VERSION HISTORY:
*
*       1.0   23/09/1997    Initial model
*       1.1   19/11/1997    Model altered for 1 gig resistors between each node and ground
*       2.0   18/12/1997    Two new parameters, ERP and ERI added
*       3.0   30/12/1997    New parameter added, RAS
*       3.1   05/01/1998    ERI parameter removed
*       3.2   06/01/1998    Fix errors in Pspice model
*       3.3   13/01/1998    Fixed errors with CDO parameter
*       3.4   25/01/1998    Errors with heater versions using ERI  fixed
*       4.1   23/01/2004    Corrections to Pspice syntax for LTSpice
**********************************************************************
.SUBCKT TRIODE A G K H1 H2
+PARAMS: RCO=1.6 RHO=10.5 HTV=6.3 HWU=10.5
+ LIP=1 LIF=3.7E-3 RAF=18E-3 RAS=1 CDO=0 RAP=4E-3
+ ERP=1.5 
+ MU0=17.3 MUR=19E-3 EMC=9.6E-6 GCO=0 GCF=213E-6
+ CGA=3.9p CGK=2.4p CAK=0.7p 

************************************************************************
*
* Heater model
*
* Can be operated from AC or DC power sources.
* NB: When operating from DC power sources, "Skip initial transient
*     solution" must be checked, to make use of this model.
*
* PARAMETERS
*
*	RCO Heater resistance cold (ohms)
*	RHO Heater resistance hot (ohms)
*	HTV Normal heater voltage (V)
* 	HWU Heater time to warm up to 90% of emission (seconds)
*
************************************************************************

Rcool H1 HA {RCO}
Rload HA HB 1M
Esens HD 0  VALUE {V(HA,HB)*1000}
Epwr  HE 0  VALUE {V(H1,H2)*V(HD)/(PWR({HTV},2)/{RHO})}
RH1   HE HF 91k
CH1   HF 0  {HWU/1E6}
EH2   HG 0  VALUE {V(HF)}
RH2   HG HH 270k
CH2   HH 0  {HWU/1E6}
EH3   HJ 0  VALUE {LIMIT(V(HH)-0.75,0,1E6)*4}
RH3   HJ HK 91k
CH3   HK 0  {HWU/1E6}
Ghot  HB H2 VALUE {(1/(V(HG)+0.001))/({RHO}-{RCO})*V(HB,H2)}

************************************************************************
*
* Anode/grid model
*
* Models reduction in mu at large negative grid voltages
* Models change in Ra with negative grid voltages
* Models limit in Ia with high +Vg and low Va
*
* PARAMETERS
*
*	LIP Conduction limit exponent
*	LIF Conduction limit factor
*	CDO Conduction offset
*	RAF Anode resistance factor for neg grid voltages
*	RAP Anode resistance factor for positive grid voltages
*	ERP Emission power
*	MU0 Mu between grid and anode at Vg=0
*	MUR Mu reduction factor for large negative grid voltages
*	EMC Emission coefficient
*	GCO Grid current offset in volts
*	GCF Grid current scale factor
*
************************************************************************

Elim  LI 0  VALUE {PWR(LIMIT(V(A,K),0,1E6),{LIP})*{LIF}}
Egg   GG 0  VALUE {V(G,K)-{CDO}}
Erpf  RP 0  VALUE {1-PWR(LIMIT(-V(GG)*{RAF},0,0.999),{RAS})+LIMIT(V(GG),0,1E6)*{RAP}}
Egr   GR 0  VALUE {LIMIT(V(GG),0,1E6)+LIMIT((V(GG))*(1+V(GG)*{MUR}),0,-1E6)}
Eem   EM 0  VALUE {LIMIT(V(A,K)+V(GR)*{MU0},0,1E6)}
Eep   EP 0  VALUE {PWR(V(EM),ERP)*{EMC}*{EMISSIONRANGE}*V(RP)}
Eel   EL 0  VALUE {LIMIT(V(EP),0,V(LI))}
Eld   LD 0  VALUE {LIMIT(V(EP)-V(LI),0,1E6)}
Ga    A  K  VALUE {V(HK)*V(EL)}

************************************************************************
*
* Grid current model
*
* Models grid current, along with rise in grid current at low Va
*
************************************************************************
Egf   GF 0  VALUE {PWR(LIMIT(V(G,K)-{GCO},0,1E6),1.5)*{GCF}}
Gg    G  K  VALUE {(V(GF)+V(LD))*V(HK)}

*
* Capacitances and anti-float resistors
*
CM1	G	K	{CGK}
CM2	A	G	{CGA}
CM3	A	K	{CAK}
RF1	A	0	1000MEG
RF2	G	0	1000MEG
RF3	K	0	1000MEG

.ENDS

.SUBCKT TRIODENH A G K
+PARAMS: LIP=1 LIF=3.7E-3 RAF=18E-3 RAS=1 CDO=0 RAP=4E-3
+ ERP=1.5
+ MU0=17.3 MUR=19E-3 EMC=9.6E-6 GCO=0 GCF=213E-6
+ CGA=3.9p CGK=2.4p CAK=0.7p 

************************************************************************
*
* Anode/grid model
*
* Models reduction in mu at large negative grid voltages
* Models change in Ra with negative grid voltages
* Models limit in Ia with high +Vg and low Va
*
* PARAMETERS
*
*	LIP Conduction limit exponent
*	LIF Conduction limit factor
*	CDO Conduction offset
*	RAF Anode resistance factor for neg grid voltages
*	RAP Anode resistance factor for positive grid voltages
*	ERP Emission power
*	MU0 Mu between grid and anode at Vg=0
*	MUR Mu reduction factor for large negative grid voltages
*	EMC Emission coefficient
*	GCO Grid current offset in volts
*	GCF Grid current scale factor
*
************************************************************************

Elim  LI 0  VALUE {PWR(LIMIT(V(A,K),0,1E6),{LIP})*{LIF}}
Egg   GG 0  VALUE {V(G,K)-{CDO}}
Erpf  RP 0  VALUE {1-PWR(LIMIT(-V(GG)*{RAF},0,0.999),{RAS})+LIMIT(V(GG),0,1E6)*{RAP}}
Egr   GR 0  VALUE {LIMIT(V(GG),0,1E6)+LIMIT((V(GG))*(1+V(GG)*{MUR}),0,-1E6)}
Eem   EM 0  VALUE {LIMIT(V(A,K)+V(GR)*{MU0},0,1E6)}
Eep   EP 0  VALUE {PWR(V(EM),ERP)*{EMC}*{EMISSIONRANGE}*V(RP)}
Eel   EL 0  VALUE {LIMIT(V(EP),0,V(LI))}
Eld   LD 0  VALUE {LIMIT(V(EP)-V(LI),0,1E6)}
Ga    A  K  VALUE {V(EL)}

************************************************************************
*
* Grid current model
*
* Models grid current, along with rise in grid current at low Va
*
************************************************************************
Egf   GF 0  VALUE {PWR(LIMIT(V(G,K)-{GCO},0,1E6),1.5)*{GCF}}
Gg    G  K  VALUE {(V(GF)+V(LD))}

*
* Capacitances and anti-float resistors
*
CM1	G	K	{CGK}
CM2	A	G	{CGA}
CM3	A	K	{CAK}
RF1	A	0	1000MEG
RF2	G	0	1000MEG
RF3	K	0	1000MEG

.ENDS
**********************************************************************
* GENERIC: 2A3
* MODEL:   NH2A3
* NOTES:   No heater model (virtual cathode)
**********************************************************************
.SUBCKT NH2A3 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1.5 LIF= .003 RAF= 1.92357959289845E-03 RAS= .98 CDO= 0 
+ RAP= 0.005 ERP= 1.55 
+ MU0= 4.2 MUR= 0.0006 EMC= 0.0000868 
+ GCO=-0.2 GCF= 0.00001 
+ CGA=1.65E-11 CGK=7.50E-12 CAK=5.50E-12
.ENDS

**********************************************************************
* GENERIC: 3CX300
* MODEL:   NH3CX300
* NOTES:   No heater model
**********************************************************************
.SUBCKT NH3CX300 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1.5 LIF= 10 RAF= 0.00536 RAS= 1 CDO= 0 
+ RAP= 0.005 ERP= 1.25 
+ MU0= 8.321 MUR= 0.0012 EMC= 0.000533 
+ GCO= 0 GCF= 0.0001 
+ CGA=1.00E-11 CGK=2.50E-11 CAK=1.00E-12
.ENDS

**********************************************************************
* GENERIC: SV6AS7
* MODEL:   NHSV6AS7
* NOTES:   No heater model
**********************************************************************
.SUBCKT NHSV6AS7 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1 LIF= 0.01 RAF= 0.0058 RAS= 0.7 CDO= 0 
+ RAP= 0.035 ERP= 1.5 
+ MU0= 2.05 MUR= 0.0017 EMC= 0.0005 
+ GCO= 0 GCF= 0 
+ CGA=1.10E-11 CGK=8.00E-12 CAK=3.00E-12
.ENDS

**********************************************************************
* GENERIC: 6BM8 / ECL82
* MODEL:   NH6BM8
* NOTES:   No heater or grid model
**********************************************************************
.SUBCKT NH6BM8 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1.5 LIF= 10 RAF= 0.030667 RAS= 5 CDO=-0.5 
+ RAP= 0.587 ERP= 1.5 
+ MU0= 50 MUR= 0.035 EMC= 0.00000256 
+ GCO= 0 GCF= 0 
+ CGA=4.00E-12 CGK=2.70E-12 CAK=4.00E-12
.ENDS

**********************************************************************
* GENERIC: 6DJ8 / ECC88
* MODEL:   NH6DJ8
* NOTES:   No heater or grid current model
**********************************************************************
.SUBCKT NH6DJ8 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1.5 LIF= 10 RAF= 0.09 RAS= 0.2 CDO= 0 
+ RAP= 0 ERP= 1.35 
+ MU0= 33 MUR= 0.02 EMC= 0.0000795 
+ GCO=-0.2 GCF= 0 
+ CGA=1.40E-12 CGK=3.30E-12 CAK=1.80E-12
.ENDS

**********************************************************************
* GENERIC: 6N1P
* MODEL:   NH6N1P
* NOTES:   No heater/grid model
**********************************************************************
.SUBCKT NH6N1P A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1.5 LIF= 10 RAF= 0.01 RAS= 1 CDO= 0 
+ RAP= 0 ERP= 1.6 
+ MU0= 37.5 MUR= 0.01 EMC= 0.000005 
+ GCO= 0 GCF= 0 
+ CGA=1.60E-12 CGK=3.20E-12 CAK=1.50E-12
.ENDS

**********************************************************************
* GENERIC: 6SN7GTB
* MODEL:   6SN7GTB
* NOTES:   Has heater model (one half of heater)
**********************************************************************
.SUBCKT 6SN7GTB A G K H1 H2
XV1 A G K H1 H2 TRIODE
+PARAMS: RCO= 3.2 RHO= 21 HTV= 6.3 HWU= 10.5 
+ LIP= 1 LIF= 0.0037 RAF= 0.02 RAS= 2 CDO= 0 
+ RAP= 0.002 ERP= 1.4 
+ MU0= 19.2642 MUR= 0.006167 EMC= 0.0000189 
+ GCO= 0 GCF= 0.000213 
+ CGA=3.90E-12 CGK=2.40E-12 CAK=7.00E-13
.ENDS

**********************************************************************
* GENERIC: 6SN7GTB
* MODEL:   NH6SN7GTB
* NOTES:   No heater model
**********************************************************************
.SUBCKT NH6SN7GTB A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1 LIF= 0.0037 RAF= 0.02 RAS= 2 CDO= 0 
+ RAP= 0.002 ERP= 1.4 
+ MU0= 19.2642 MUR= 0.006167 EMC= 0.0000189 
+ GCO= 0 GCF= 0.000213 
+ CGA=3.90E-12 CGK=2.40E-12 CAK=7.00E-13
.ENDS

**********************************************************************
* GENERIC: D3a/7721
* MODEL: NHD3a
* Notes: No heater model
**********************************************************************
.SUBCKT NHD3a A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1 LIF= 1E-3 RAF= 240E-3 RAS= 2 CDO= -0.16
+ RAP= 8E-3 ERP= 1.5
+ MU0= 70 MUR= 1.5E-3 EMC= 4.7E-5
+ GCO= -0.16 GCF= 213E-6
+CGA= 2.7E-12 CGK= 7.3E-12 CAK=3.1E-12
.ENDS

**********************************************************************
* GENERIC: 12AT7 / ECC81
* MODEL:   12AT7
* NOTES:   Heater model for one half of heater (6.3V)
**********************************************************************
.SUBCKT 12AT7 A G K H1 H2
XV1 A G K H1 H2 TRIODE
+PARAMS: RCO= 6.2 RHO= 42 HTV= 6.3 HWU= 10.5 
+ LIP= 1 LIF= 0.0037 RAF= 0.09869 RAS= 1 CDO=-0.5 
+ RAP= 0.1 ERP= 1.4 
+ MU0= 45.093 MUR= 0.012937 EMC= 0.00000863 
+ GCO=-0.5 GCF= 0.00012 
+ CGA=1.60E-12 CGK=2.30E-12 CAK=4.00E-13
.ENDS

**********************************************************************
* GENERIC: 12AT7 / ECC81
* MODEL:   NH12AT7
* NOTES:   No heater model
**********************************************************************
.SUBCKT NH12AT7 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1 LIF= 0.0037 RAF= 0.09869 RAS= 1 CDO=-0.5 
+ RAP= 0.1 ERP= 1.4 
+ MU0= 45.093 MUR= 0.012937 EMC= 0.00000863 
+ GCO=-0.5 GCF= 0.00012 
+ CGA=1.60E-12 CGK=2.30E-12 CAK=4.00E-13
.ENDS

**********************************************************************
* GENERIC: 12AU7 / ECC82
* MODEL:   12AU7
* NOTES:   Heater model for one half of heater (6.3V)
**********************************************************************
.SUBCKT 12AU7 A G K H1 H2
XV1 A G K H1 H2 TRIODE
+PARAMS: RCO= 6.2 RHO= 42 HTV= 6.3 HWU= 10.5 
+ LIP= 1 LIF= 0.0037 RAF= 0.024778659 RAS= 2.040491735 CDO= 0 
+ RAP= 0.18 ERP= 1.35 
+ MU0= 14.27427 MUR= 0.005857103 EMC= 0.0000236 
+ GCO= 0 GCF= 0.00012 
+ CGA=1.60E-12 CGK=1.80E-12 CAK=4.50E-13
.ENDS

**********************************************************************
* GENERIC: 12AU7 / ECC82
* MODEL:   NH12AU7
* NOTES:   No heater model
**********************************************************************
.SUBCKT NH12AU7 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1 LIF= 0.0037 RAF= 0.000001 RAS= 2.065382774 CDO= 0 
+ RAP= 0.18 ERP= 1.4 
+ MU0= 17.08958652 MUR= 0.010938375 EMC= 0.0000183 
+ GCO= 0 GCF= 0.00012 
+ CGA=1.60E-12 CGK=1.80E-12 CAK=4.50E-13
.ENDS

**********************************************************************
* GENERIC: 12AX7 / ECC83
* MODEL:   12AX7
* NOTES:   Heater model for one half of heater (6.3V)
**********************************************************************
.SUBCKT 12AX7 A G K H1 H2
XV1 A G K H1 H2 TRIODE
+PARAMS: RCO= 6.2 RHO= 42 HTV= 6.3 HWU= 10.5 
+ LIP= 1.5 LIF= 0.000016 RAF= 0.076498 RAS= 1 CDO=-0.53056 
+ RAP= 0.18 ERP= 1.5 
+ MU0= 87.302 MUR=-0.013621 EMC= 0.00000111 
+ GCO=-0.2 GCF= 0.00001 
+ CGA=3.90E-12 CGK=2.40E-12 CAK=7.00E-13
.ENDS

**********************************************************************
* GENERIC: 12AX7 / ECC83
* MODEL:   NH12AX7
* NOTES:   No heater model
**********************************************************************
.SUBCKT NH12AX7 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1.5 LIF= 0.000016 RAF= 0.076498 RAS= 1 CDO=-0.53056 
+ RAP= 0.18 ERP= 1.5 
+ MU0= 87.302 MUR=-0.013621 EMC= 0.00000111 
+ GCO=-0.2 GCF= 0.00001 
+ CGA=3.90E-12 CGK=2.40E-12 CAK=7.00E-13
.ENDS

**********************************************************************
* GENERIC: 76
* MODEL:   NH76
* NOTES:   No heater/grid model
**********************************************************************
.SUBCKT NH76 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1 LIF= 10 RAF= 0.015 RAS= 1.8 CDO= 0 
+ RAP= 0 ERP= 1.6 
+ MU0= 12.8 MUR= 0.001 EMC= 0.000008 
+ GCO= 0 GCF= 0 
+ CGA=2.80E-12 CGK=3.50E-12 CAK=2.50E-12
.ENDS

**********************************************************************
* GENERIC: 300B
* MODEL:   NH300B
* NOTES:   No heater/grid model (virtual cathode)
**********************************************************************
.SUBCKT NH300B A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1 LIF= 10 RAF= 0.00311 RAS= 1.013608 CDO= 0 
+ RAP= 0 ERP= 1.5 
+ MU0= 3.7992 MUR= 0.000362 EMC= 0.000116 
+ GCO= 0 GCF= 0 
+ CGA=1.50E-11 CGK=9.00E-12 CAK=4.30E-12
.ENDS

**********************************************************************
* GENERIC: SV572-3
* MODEL:   SV5723
* NOTES:   No heater model (virtual cathode)
**********************************************************************
.SUBCKT SV5723 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1 LIF= 0.0018 RAF= 0.0012 RAS= 0.5 CDO= 0 
+ RAP= 0 ERP= 1.4 
+ MU0= 3.79928 MUR= 0.0002 EMC= 0.0000425 
+ GCO= 0 GCF= 0.0000349 
+ CGA=4.00E-12 CGK=4.00E-12 CAK=1.00E-12
.ENDS

**********************************************************************
* GENERIC: SV572-10
* MODEL:   SV57210
* NOTES:   This model is not accurate for Vg >= +60V
**********************************************************************
.SUBCKT SV57210 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1.4 LIF= 0.0008 RAF= 0.001 RAS= 1 CDO= 0 
+ RAP=-0.00117 ERP= 1.38 
+ MU0= 10 MUR= 0.0001 EMC= 0.0000272 
+ GCO=-0.2 GCF= 0.0003 
+ CGA=5.00E-12 CGK=6.40E-12 CAK=1.00E-12
.ENDS

**********************************************************************
* GENERIC: 5751
* MODEL:   NH5751
* NOTES:   No heater model
**********************************************************************
.SUBCKT NH5751 A G K
XV1 A G K TRIODENH
+PARAMS: LIP= 1.5 LIF= 0.000016 RAF= 0.075772 RAS= 1 CDO=-0.53056 
+ RAP= 0.131285 ERP= 1.5 
+ MU0= 62.94685 MUR=-0.0111 EMC= 0.00000142 
+ GCO=-0.2 GCF= 0.00001 
+ CGA=1.40E-12 CGK=1.40E-12 CAK=4.50E-13
.ENDS

.subckt 6C45-PE 1 2 3 ; plate grid cathode
+ params: mu=47.4501 ex=2.374193 kg1=268.615545 kp=485.735371 kvb=501.503636 rgi=300
+ ccg=2.4p cgp=4p ccp=.7p
e1 7 0 value= {v(1,3)/kp*log(1+exp(kp*(1/mu+v(2,3)/sqrt(kvb+v(1,3)*v(1,3)))))}
re1 7 0 1g
g1 1 3 value= {(pwr(v(7),ex)+pwrs(v(7),ex))/kg1}
rcp 1 3 1g
c1 2 3 {ccg}
c2 1 2 {cgp}
c3 1 3 {ccp}
r1 2 5 {rgi}
d3 5 3 dx
.model dx d(is=1n rs=1 cjo=10pf tt=1n)
.ends

.subckt VT4C 1 3 4 ; TRIODO DI POTENZA D.H.T. ( G.E.)
g1 2 4 value = {(exp(1.5*(log((v(2,4)/12)+v(3,4)))))/3010}
c1 3 4 6p
c2 3 1 14.5p
c3 1 4 5.5p
r1 3 5 10k
d1 1 2 dx
d2 4 2 dx2
d3 5 4 dx
.model dx d(is=1p rs=1)
.model dx2 d(is=1n rs=1)
.ends VT4C ; eq. 211A

.SUBCKT GL211  P G K
E1  2  0  VALUE={V(P,K)+12.11*V(G,K)}
R1  2  0  1.0K
Gp  P  K  VALUE={9.39E-6*(PWR(V(2),1.5)+PWRS(V(2),1.5))/2}
Gg  G  K  VALUE={358E-6*(PWR(V(G,K),1.5)+PWRS(V(G,K),1.5))/2}
Cgk G  K  6.0P
Cgp G  P  14.5P
Cpk P  K  5.5P
.ENDS GL211


****************************************************************************
* Federico Scarpa models
* http://www.geocities.com/koren_model/
*
* Note that these use the model from Norman Koren.
*
****************************************************************************

.SUBCKT k2a3_sofia A G K
+PARAMS: MU=4.545 ERP=1.5
+ KK1=1744 KP=41.4 KVB=17.1 vg0=1.5
+ CGA=16.5p CGK=7.5p CAK=5.5p RGI=1000
*.param V_6={KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )} 
*****************************************************************
.func V_6() {KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )} 
E8 8 0 VALUE={(V(A,K))/KP*LN(1+EXP(V_6()))}
Eam am 0 VALUE= {2*Pow(V(8),ERP)/KK1}
GA A K VALUE={V(am)}
D3 5 k DX ; FOR GRID CURRENT
R1 g 5 {RGI} ; FOR GRID CURRENT
Rak A K 1G
Rgk G K 1G
C1 G K {CGK}
C2 G A {CGA}
C3 A K {CAK}
.MODEL DX D(IS=1N RS=1)
.ENDS

.SUBCKT k300bb_sofia  A G K
+PARAMS: MU=4.16 ERP=1.5
+ KK1=1922 KP=45.5 KVB=7 vg0=3
+ CGA=15.p CGK=9.p CAK=4.3p RGI=1000

*.param V_6={KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )}
************************************************************************ 
.func V_6() {KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )}

E8    8  0  VALUE={(V(A,K))/KP*LN(1+EXP(V_6()))}

Eam   am  0  VALUE= {2*Pow(V(8),ERP)/KK1}
GA    A  K  VALUE={V(am)}

D3    5 k DX     ; FOR GRID CURRENT
R1    g 5 {RGI}  ; FOR GRID CURRENT
Rak   A  K  1G
Rgk   G  K  1G

C1    G  K  {CGK}
C2    G  A  {CGA}
C3    A  K  {CAK}
.MODEL DX D(IS=1N RS=1)
.ENDS	

.SUBCKT k5687wa  A G K
+PARAMS: MU=18.14 ERP=1.48
+ KK1=665 KP=128.5 KVB=13.6 vg0=-0.7
+ CGA=5.2p CGK=5.2p CAK=0.8p RGI=1000

*.param V_6={KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )}
************************************************************************ 
.func V_6() {KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )}

E8    8  0  VALUE={(V(A,K))/KP*LN(1+EXP(V_6()))}

Eam   am  0  VALUE= {2*Pow(V(8),ERP)/KK1}
GA    A  K  VALUE={V(am)}

D3    5 k DX     ; FOR GRID CURRENT
R1    g 5 {RGI}  ; FOR GRID CURRENT
Rak   A  K  1G
Rgk   G  K  1G

C1    G  K  {CGK}
C2    G  A  {CGA}
C3    A  K  {CAK}
.MODEL DX D(IS=1N RS=1)
.ENDS		

.SUBCKT k6c33c_sofia A G K
+PARAMS: MU=2.67 ERP=1.45
+ KK1=418 KP=14.6 KVB=5
+ CGA=30p CGK=30p CAK=10p RGI=1000
*.param V_6={KP*( (1/MU)+(V(G,K)/sqrt(V(A,K)**2+KVB**2)) )} 
************************************************************************
.func V_6() {KP*( (1/MU)+(V(G,K)/sqrt(V(A,K)**2+KVB**2)) )} 
E8 8 0 VALUE={(V(A,K))/KP*LN(1+EXP(V_6()))}
Eam am 0 VALUE= {2*Pow(V(8),ERP)/KK1}
GA A K VALUE={V(am)}
D3 5 k DX ; FOR GRID CURRENT
R1 g 5 {RGI} ; FOR GRID CURRENT
Rak A K 1G
Rgk G K 1G
C1 G K {CGK}
C2 G A {CGA}
C3 A K {CAK}
.MODEL DX D(IS=1N RS=1) 
.ENDS

.SUBCKT k6c4c  A G K
+PARAMS: MU=4.4 ERP=1.5
+ KK1=2136 KP=49.5 KVB=23 vg0=-3
+ CGA=16.5p CGK=7.5p CAK=5.5p RGI=1000   ;(2A3 values)

*.param V_6={KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )}
************************************************************************ 
.func V_6() {KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )}

E8    8  0  VALUE={(V(A,K))/KP*LN(1+EXP(V_6()))}

Eam   am  0  VALUE= {2*Pow(V(8),ERP)/KK1}
GA    A  K  VALUE={V(am)}

D3    5 k DX     ; FOR GRID CURRENT
R1    g 5 {RGI}  ; FOR GRID CURRENT
Rak   A  K  1G
Rgk   G  K  1G

C1    G  K  {CGK}
C2    G  A  {CGA}
C3    A  K  {CAK}
.MODEL DX D(IS=1N RS=1)
.ENDS

.SUBCKT k6sn7_sofia A G K
+PARAMS: MU=21.95 ERP=1.5
+ KK1=2100 KP=169 KVB=4 vg0=-.45
+ CGA=4p CGK=3p CAK=1.2p RGI=1000
*.param V_6={KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )} 
******************************************************************
.func V_6() {KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )} 
E8 8 0 VALUE={(V(A,K))/KP*LN(1+EXP(V_6()))}
Eam am 0 VALUE= {2*Pow(V(8),ERP)/KK1}
GA A K VALUE={V(am)}
D3 5 k DX ; FOR GRID CURRENT
R1 g 5 {RGI} ; FOR GRID CURRENT
Rak A K 1G
Rgk G K 1G
C1 G K {CGK}
C2 G A {CGA}
C3 A K {CAK}
.MODEL DX D(IS=1N RS=1)
.ENDS

.SUBCKT kel34_sofia A G K
+PARAMS: MU=11.17 ERP=1.48
+ KK1=597 KP=40.5 KVB=24.6 vg0=-.4
+ CGA=1.1p CGK=15p CAK=8.5p RGI=1000
*.param V_6={KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )} 
************************************************************************ 
.func V_6() {KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )} 
E8 8 0 VALUE={(V(A,K))/KP*LN(1+EXP(V_6()))}
Eam am 0 VALUE= {2*Pow(V(8),ERP)/KK1}
GA A K VALUE={V(am)}
D3 5 k DX ; FOR GRID CURRENT
R1 g 5 {RGI} ; FOR GRID CURRENT
Rak A K 1G
Rgk G K 1G
C1 G K {CGK}
C2 G A {CGA}
C3 A K {CAK}
.MODEL DX D(IS=1N RS=1)
.ENDS

.SUBCKT kecc99 A G K 
+PARAMS: MU=23.33 ERP=1.48
+ KK1=448.5 KP=172.65 KVB=8.92
+ CGA=5p CGK=6p CAK=1p RGI=1000
*.param V_6={KP*( (1/MU)+(V(G,K)/sqrt(V(A,K)**2+KVB**2)) )} 
********************************************************************
.func V_6() {KP*( (1/MU)+(V(G,K)/sqrt(V(A,K)**2+KVB**2)) )} 
E8 8 0 VALUE={(V(A,K))/KP*LN(1+EXP(V_6()))}
Eam am 0 VALUE= {2*Pow(V(8),ERP)/KK1}
GA A K VALUE={V(am)}
D3 5 k DX ; FOR GRID CURRENT
R1 g 5 {RGI} ; FOR GRID CURRENT
Rak A K 1G
Rgk G K 1G
C1 G K {CGK}
C2 G A {CGA}
C3 A K {CAK}
.MODEL DX D(IS=1N RS=1)
.ENDS

.SUBCKT kvv30b_sofia  A G K
+PARAMS: MU=3.775 ERP=1.52
+ KK1=2230 KP=43.6 KVB=5 vg0=4
+ CGA=15.p CGK=9.p CAK=4.3p RGI=1000 ; 300b cap values

*.param V_6={KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )}
************************************************************************ 
.func V_6() {KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )}

E8    8  0  VALUE={(V(A,K))/KP*LN(1+EXP(V_6()))}

Eam   am  0  VALUE= {2*Pow(V(8),ERP)/KK1}
GA    A  K  VALUE={V(am)}

D3    5 k DX     ; FOR GRID CURRENT
R1    g 5 {RGI}  ; FOR GRID CURRENT
Rak   A  K  1G
Rgk   G  K  1G

C1    G  K  {CGK}
C2    G  A  {CGA}
C3    A  K  {CAK}
.MODEL DX D(IS=1N RS=1)
.ENDS	

.SUBCKT kGM70  A G K
+PARAMS: MU=8.037 ERP=1.5
+ KK1=4121 KP=182.25 KVB=34 vg0=-5.7
+ CGA=12.p CGK=8.p CAK=4.p RGI=1000
*.param V_6=KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )
***************************************************************l
.func   V_6() {KP*( (1/MU)+((V(G,K)-vg0)/sqrt(V(A,K)**2+KVB**2)) )}

E8    8  0  VALUE={(V(A,K))/KP*LN(1+EXP(V_6()))}

Eam   am  0  VALUE= {2*Pow(V(8),ERP)/KK1}
GA    A  K  VALUE={V(am)}

D3    5 k DX     ; FOR GRID CURRENT
R1    g 5 {RGI}  ; FOR GRID CURRENT
Rak   A  K  1G
Rgk   G  K  1G

C1    G  K  {CGK}
C2    G  A  {CGA}
C3    A  K  {CAK}
.MODEL DX D(IS=1N RS=1)
.ENDS

************* Aernoud Dekker additions ********************

.subckt Ba  P G K
    Bp  P K  I=(0.0004817939578m)*uramp(V(P,K)*ln(1.0+(-0.3768201078)+exp((8.811478483)+(8.811478483)*((19.34729852)+(163.4465246m)*V(G,K))*V(G,K)/sqrt((-3.388214357e-005)**2+(V(P,K)-(-35.30179442))**2)))/(8.811478483))**(1.791391702)
.ends Ba

* VT25 RCA LTSpice model
.subckt VT25  P G K
    Bp  P K  I=(0.006703379527m)*uramp(V(P,K)*ln(1.0+(-0.273570337)+exp((18.46077943)+(18.46077943)*((7.636448964)+(-2.487355794m)*V(G,K))*V(G,K)/sqrt((63.81261404)**2+(V(P,K)-(24.01493965))**2)))/(18.46077943))**(1.582695269)
.ends VT25

* 205D LTSpice model
.subckt 205D  P G K
    Bp  P K  I=(0.009509114467m)*uramp(V(P,K)*ln(1.0+(-0.4134930726)+exp((3.08305068)+(3.08305068)*((7.060954231)+(-19.03362103m)*V(G,K))*V(G,K)/sqrt((5.501519156e-006)**2+(V(P,K)-(25.94890019))**2)))/(3.08305068))**(1.544222766)
.ends 205D

* WE437A LTSpice model
.subckt WE437A  P G K
    Bp  P K  I=(0.03233120009m)*uramp(V(P,K)*ln(1.0+(-0.3349595052)+exp((0.6125957812)+(0.6125957812)*((73.57576036)+(-5662.847759m)*V(G,K))*V(G,K)/sqrt((-49.16952176)**2+(V(P,K)-(42.26357906))**2)))/(0.6125957812))**(1.577098566)
.ends WE437A

* RE404 LTSpice model
.subckt RE404  P G K
    Bp  P K  I=(0.002264775164m)*uramp(V(P,K)*ln(1.0+(-0.2683633726)+exp((2.812915322)+(2.812915322)*((28.75948593)+(160.3524095m)*V(G,K))*V(G,K)/sqrt((8.401152905e-006)**2+(V(P,K)-(-3.412685905))**2)))/(2.812915322))**(1.768723197)
.ends RE404